@@ -13,12 +13,12 @@
  * for C-Ares */
 #define CARES_HAVE_SYS_TYPES_H
 #define CARES_HAVE_SYS_SOCKET_H
+#define CARES_HAVE_SYS_SELECT_H
 /* #undef CARES_HAVE_WINDOWS_H */
 /* #undef CARES_HAVE_WS2TCPIP_H */
 /* #undef CARES_HAVE_WINSOCK2_H */
-/* #undef CARES_HAVE_WINDOWS_H */
 #define CARES_HAVE_ARPA_NAMESER_H
-/* #undef CARES_HAVE_ARPA_NAMESER_COMPAT_H */
+#define CARES_HAVE_ARPA_NAMESER_COMPAT_H
 
 #ifdef CARES_HAVE_SYS_TYPES_H
 #  include <sys/types.h>
@@ -28,6 +28,10 @@
 #  include <sys/socket.h>
 #endif
 
+#ifdef CARES_HAVE_SYS_SELECT_H
+#  include <sys/select.h>
+#endif
+
 #ifdef CARES_HAVE_WINSOCK2_H
 #  include <winsock2.h>
 #endif
@@ -40,8 +44,4 @@
 #  include <windows.h>
 #endif
 
-
-typedef CARES_TYPEOF_ARES_SOCKLEN_T ares_socklen_t;
-typedef CARES_TYPEOF_ARES_SSIZE_T ares_ssize_t;
-
 #endif /* __CARES_BUILD_H */
